@@ -9,13 +9,14 @@ our @ISA       = qw(Exporter);
 our @EXPORT    = qw(spork);
 our @EXPORT_OK = qw(daemonize);
 
-use version;our $VERSION = qv('0.0.2');
+use version;our $VERSION = qv('0.0.3');
 use POSIX 'setsid';
 
 sub spork {
     my $spork = shift;
     croak "spork() needs a code ref!" if ref $spork ne 'CODE';
-    defined(my $pid = fork) or croak qq{Couldn't fork for spork: $!};
+    $SIG{'CHLD'} = 'IGNORE';
+    defined(my $pid = fork) or return; # croak qq{Couldn't fork for spork: $!};
     if($pid) { 
         return $pid; 
     } 
@@ -41,13 +42,14 @@ Acme::Spork - Perl extension for spork()ing in your script
 
 =head1 SYNOPSIS
 
-  use Acme::Spork;
-  my $spork_pid = spork(\&long_running_code, @ARGV);
-  print "Long running code has been started as PID $spork_pid, bye!\n";
+    use Acme::Spork;
+    my $spork_pid = spork(\&long_running_code, @ARGV) 
+        or die "Could not fork for spork: $!";
+    print "Long running code has been started as PID $spork_pid, bye!\n";
 
 =head1 DESCRIPTION
 
-A spork in plastic sense is a fork combined with a spoon. In programming I've come to call a spork() a fork() that does more than just a fork.
+A spork in the plastic sense is a fork combined with a spoon. In programming I've come to call a spork() a fork() that does more than just a fork.
 
 I use it to describe when you want to fork() to run some long running code but immediately return to the main program instead of waiting for it.
 
@@ -69,13 +71,23 @@ The first argument is a code ref that gets executed and any other args are passe
             print {$log_fh} "I am spork hear me spoon\n"; 
             close $log_fh;
         },
-    );
+    ) or die qq{Couldn't fork for spork: $!};
     print 2;
 
 This prints out "12" immediately and is done running, now if you tail -f spork.log you'll see "I am spork hear me spoon\n" get written to it 4 or 5 seconds later by the spork()ed process :)
 
 spork() returns the PID of the spork()ed process so you can keep track of them and do what you need with it.
 
+If it returns false then fork failed so you can:
+
+    if(spork(\&foo)) {
+        print "I am spork here me spoon\n";
+    }
+    else {
+        print "Could not fork for spork: $!";
+    }
+    my $spork_pid = spork(\&foo) or die "Could not fork for for spork: $!";
+
 =head1 daemonize()
 
 Since many daemons need to spork a child process when a request is received I've included a cheat function to daemonize your script execution.
@@ -93,7 +105,13 @@ Its simply a wrapper for Proc::Daemon::Init.
     # and handle requests as a server:
     while(<$incoming_requests>) {
         my $req_pid = spork(\&handle_request($_));
-        spork(\&log_request($_), $req_pid);
+        if($req_pid) {
+            spork(\&log_request($_), $req_pid) 
+                or warn "Could not spork log request $req_pid: $!";
+        }
+        else {
+            warn "Could not spork request: $!";
+        }
     }
     
 
